@@ -4,16 +4,16 @@
 
  (C) COPYRIGHT 2002, Andrea Campi <a.campi@inet.it>
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at https://www.mozilla.org/MPL/
  ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
@@ -55,7 +55,6 @@ icalattach *icalattach_new_from_data(const char *data, icalattach_free_fn_t free
                                      void *free_fn_data)
 {
     icalattach *attach;
-    char *data_copy;
 
     icalerror_check_arg_rz((data != NULL), "data");
 
@@ -64,15 +63,9 @@ icalattach *icalattach_new_from_data(const char *data, icalattach_free_fn_t free
         return NULL;
     }
 
-    if ((data_copy = strdup(data)) == NULL) {
-        free(attach);
-        errno = ENOMEM;
-        return NULL;
-    }
-
     attach->refcount = 1;
     attach->is_url = 0;
-    attach->u.data.data = data_copy;
+    attach->u.data.data = (char *) data;
     attach->u.data.free_fn = free_fn;
     attach->u.data.free_fn_data = free_fn_data;
 
@@ -99,12 +92,8 @@ void icalattach_unref(icalattach *attach)
 
     if (attach->is_url) {
         free(attach->u.url.url);
-    } else {
-        free(attach->u.data.data);
-/* unused for now
-        if (attach->u.data.free_fn)
-           (* attach->u.data.free_fn) (attach->u.data.data, attach->u.data.free_fn_data);
-*/
+    } else if (attach->u.data.free_fn) {
+        (* attach->u.data.free_fn) (attach->u.data.data, attach->u.data.free_fn_data);
     }
 
     free(attach);
