@@ -2,45 +2,33 @@
  FILE: icalmemory.c
  CREATOR: eric 30 June 1999
 
- Copyright (C) 2000 Eric Busboom <eric@softwarestudio.org>
-   http://www.softwarestudio.org
+ Copyright (C) 2000 Eric Busboom <eric@civicknowledge.com>
 
- The contents of this file are subject to the Mozilla Public License
- Version 1.0 (the "License"); you may not use this file except in
- compliance with the License. You may obtain a copy of the License at
- http://www.mozilla.org/MPL/
-
- Software distributed under the License is distributed on an "AS IS"
- basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
- the License for the specific language governing rights and
- limitations under the License.
-
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at https://www.mozilla.org/MPL/
+
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of either:
+
+    The LGPL as published by the Free Software Foundation, version
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+
+ Or:
+
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at https://www.mozilla.org/MPL/
 ======================================================================*/
 
 /**
  * @file icalmemory.c
- * @brief Common memory management routines.
- *
- * libical often passes strings back to the caller. To make these
- * interfaces simple, I did not want the caller to have to pass in a
- * memory buffer, but having libical pass out newly allocated memory
- * makes it difficult to de-allocate the memory.
- *
- * The ring buffer in this scheme makes it possible for libical to pass
- * out references to memory which the caller does not own, and be able
- * to de-allocate the memory later. The ring allows libical to have
- * several buffers active simultaneously, which is handy when creating
- * string representations of components.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,7 +40,16 @@
 
 #include <stdlib.h>
 
+/**
+ * @brief Determines the size of the ring buffer used for keeping track of
+ * temporary buffers.
+ */
 #define BUFFER_RING_SIZE 2500
+
+/**
+ * @brief Determines the minimal size of buffers in the ring that are created
+ * with icalmemory_tmp_buffer().
+ */
 #define MIN_BUFFER_SIZE 200
 
 /* HACK. Not threadsafe */
@@ -64,10 +61,17 @@ typedef struct
 } buffer_ring;
 
 #if !defined(HAVE_PTHREAD)
+/**
+ * @private
+ */
 static buffer_ring *global_buffer_ring = 0;
 #endif
 
-/** get rid of this buffer ring */
+/**
+ * @private
+ *
+ * Get rid of this buffer ring.
+ */
 static void icalmemory_free_ring_byval(buffer_ring * br)
 {
     int i;
@@ -114,6 +118,9 @@ static void icalmemory_free_tmp_buffer(void *buf)
 
 #endif
 
+/**
+ * @private
+ */
 static buffer_ring *buffer_ring_new(void)
 {
     buffer_ring *br;
@@ -129,6 +136,9 @@ static buffer_ring *buffer_ring_new(void)
 }
 
 #if defined(HAVE_PTHREAD)
+/**
+ * @private
+ */
 static buffer_ring *get_buffer_ring_pthread(void)
 {
     buffer_ring *br;
@@ -145,7 +155,11 @@ static buffer_ring *get_buffer_ring_pthread(void)
 }
 
 #else
-/* get buffer ring via a single global for a non-threaded program */
+/**
+ * @private
+ *
+ * Get buffer ring via a single global for a non-threaded program
+ */
 static buffer_ring *get_buffer_ring_global(void)
 {
     if (global_buffer_ring == 0) {
@@ -156,6 +170,9 @@ static buffer_ring *get_buffer_ring_global(void)
 
 #endif
 
+/**
+ * @private
+ */
 static buffer_ring *get_buffer_ring(void)
 {
 #if defined(HAVE_PTHREAD)
@@ -165,7 +182,7 @@ static buffer_ring *get_buffer_ring(void)
 #endif
 }
 
-/** Add an existing buffer to the buffer ring */
+/* Add an existing buffer to the buffer ring */
 void icalmemory_add_tmp_buffer(void *buf)
 {
     buffer_ring *br = get_buffer_ring();
@@ -184,7 +201,7 @@ void icalmemory_add_tmp_buffer(void *buf)
     br->ring[br->pos] = buf;
 }
 
-/**
+/*
  * Create a new temporary buffer on the ring. Libical owns these and
  * will deallocate them.
  */
@@ -225,7 +242,7 @@ void icalmemory_free_ring()
 #endif
 }
 
-/** Like strdup, but the buffer is on the ring. */
+/* Like strdup, but the buffer is on the ring. */
 char *icalmemory_tmp_copy(const char *str)
 {
     char *b = icalmemory_tmp_buffer(strlen(str) + 1);
