@@ -2,21 +2,20 @@
  FILE: icaltime.c
  CREATOR: eric 02 June 2000
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
  The timegm code is Copyright (c) 2001-2006, NLnet Labs. All rights reserved.
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at https://www.mozilla.org/MPL/
 
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -181,27 +180,6 @@ static time_t make_time(struct tm *tm, int tzm)
     return (tim);
 }
 
-/**     @brief Constructor (deprecated).
- *
- * Convert seconds past UNIX epoch to a timetype.
- *
- * @deprecated This constructor is deprecated and shouldn't be used in
- *   new software.  Use icaltime_from_timet_with_zone(time_t, int,
- *   icaltimezone *) instead.  In the meantime, calls to this method
- *   return a floating time, which can always be converted to a local
- *   time with an appropriate call to icaltime_convert_to_zone().
- */
-
-struct icaltimetype icaltime_from_timet(const time_t tm, const int is_date)
-{
-#if NO_WARN_DEPRECATED == 0
-    icalerror_warn(
-        "icaltime_from_timet() is DEPRECATED, use icaltime_from_timet_with_zone() instead");
-#endif
-
-    return icaltime_from_timet_with_zone(tm, is_date, 0);
-}
-
 /**     @brief Constructor.
  *
  *      @param tm The time
@@ -236,7 +214,8 @@ struct icaltimetype icaltime_from_timet_with_zone(const time_t tm, const int is_
     utc_zone = icaltimezone_get_utc_timezone();
 
     /* Convert the time_t to a struct tm in UTC time. We can trust gmtime for this. */
-    gmtime_r(&tm, &t);
+    if (!gmtime_r(&tm, &t))
+        return is_date ? icaltime_null_date () : icaltime_null_time ();
 
     tt.year = t.tm_year + 1900;
     tt.month = t.tm_mon + 1;
@@ -245,9 +224,8 @@ struct icaltimetype icaltime_from_timet_with_zone(const time_t tm, const int is_
     tt.minute = t.tm_min;
     tt.second = t.tm_sec;
     tt.is_date = 0;
-    tt.is_utc = (zone == utc_zone) ? 1 : 0;
     tt.is_daylight = 0;
-    tt.zone = NULL;
+    tt.zone = (zone == NULL) ? NULL : utc_zone;
 
     /* Use our timezone functions to convert to the required timezone. */
     icaltimezone_convert_time(&tt, utc_zone, (icaltimezone *) zone);
@@ -282,14 +260,6 @@ struct icaltimetype icaltime_today(void)
     return icaltime_from_timet_with_zone(time(NULL), 1, NULL);
 }
 
-/**     @brief  Return the time as seconds past the UNIX epoch
- *
- *      While this function is not currently deprecated, it probably won't do
- *      what you expect, unless you know what you're doing. In particular, you
- *      should only pass an icaltime in UTC, since no conversion is done. Even
- *      in that case, it's probably better to just use
- *      icaltime_as_timet_with_zone().
- */
 time_t icaltime_as_timet(const struct icaltimetype tt)
 {
     struct tm stm;
@@ -394,7 +364,7 @@ char *icaltime_as_ical_string_r(const struct icaltimetype tt)
     } else {
         const char *fmt;
 
-        if (tt.is_utc) {
+        if (icaltime_is_utc(tt)) {
             fmt = "%04d%02d%02dT%02d%02d%02dZ";
         } else {
             fmt = "%04d%02d%02dT%02d%02d%02d";
@@ -441,17 +411,14 @@ struct icaltimetype icaltime_from_string(const char *str)
     size = strlen(str);
 
     if ((size == 15) || (size == 19)) { /* floating time with/without separators */
-        tt.is_utc = 0;
         tt.is_date = 0;
     } else if ((size == 16) || (size == 20)) {  /* UTC time, ends in 'Z' */
-        if ((str[15] != 'Z') && (str[19] != 'Z'))
+        if ((str[size-1] != 'Z'))
             goto FAIL;
 
-        tt.is_utc = 1;
         tt.zone = icaltimezone_get_utc_timezone();
         tt.is_date = 0;
     } else if ((size == 8) || (size == 10)) {   /* A DATE */
-        tt.is_utc = 0;
         tt.is_date = 1;
     } else {    /* error */
         goto FAIL;
@@ -600,20 +567,6 @@ int icaltime_start_doy_week(const struct icaltimetype t, int fdow)
     return jt.day_of_year - delta;
 }
 
-/** Day of the year that the first day of the week (Sunday) is on.
- *
- *  @deprecated Doesn't take into account different week start days.
- */
-int icaltime_start_doy_of_week(const struct icaltimetype t)
-{
-#if NO_WARN_DEPRECATED == 0
-    icalerror_warn(
-        "icaltime_start_doy_of_week() is DEPRECATED, use icaltime_start_doy_week() instead");
-#endif
-
-    return icaltime_start_doy_week(t, 1);
-}
-
 /**
  * @todo Doesn't take into account the start day of the
  * week. strftime assumes that weeks start on Monday.
@@ -731,8 +684,7 @@ struct icaltimetype icaltime_null_date(void)
  */
 int icaltime_is_valid_time(const struct icaltimetype t)
 {
-    if (t.is_utc > 1 || t.is_utc < 0 ||
-        t.year < 0 || t.year > 3000 || t.is_date > 1 || t.is_date < 0) {
+    if (t.year < 0 || t.year > 3000 || t.is_date > 1 || t.is_date < 0) {
         return 0;
     } else {
         return 1;
@@ -752,7 +704,7 @@ int icaltime_is_date(const struct icaltimetype t)
  */
 int icaltime_is_utc(const struct icaltimetype t)
 {
-    return t.is_utc;
+    return t.zone == icaltimezone_get_utc_timezone();
 }
 
 /**
@@ -777,8 +729,9 @@ int icaltime_compare(const struct icaltimetype a_in, const struct icaltimetype b
 {
     struct icaltimetype a, b;
 
-    /* We only need to perform time zone conversion if times aren't in the same time zone */
-    if (a_in.zone != b_in.zone || a_in.is_utc != b_in.is_utc) {
+    /* We only need to perform time zone conversion if times aren't in the same time zone
+       or neither of them is floating (zone equals NULL) */
+    if (a_in.zone != b_in.zone && a_in.zone != NULL && b_in.zone != NULL) {
         a = icaltime_convert_to_zone(a_in, icaltimezone_get_utc_timezone());
         b = icaltime_convert_to_zone(b_in, icaltimezone_get_utc_timezone());
     } else {
@@ -1017,7 +970,7 @@ struct icaltimetype icaltime_convert_to_zone(const struct icaltimetype tt, icalt
     }
 
     /* If it's a floating time we don't want to adjust the time */
-    if (tt.zone != NULL || tt.is_utc) {
+    if (tt.zone != NULL) {
         icaltimezone *from_zone = (icaltimezone *) tt.zone;
 
         if (!from_zone) {
@@ -1028,11 +981,6 @@ struct icaltimetype icaltime_convert_to_zone(const struct icaltimetype tt, icalt
     }
 
     ret.zone = zone;
-    if (zone == icaltimezone_get_utc_timezone()) {
-        ret.is_utc = 1;
-    } else {
-        ret.is_utc = 0;
-    }
 
     return ret;
 }
@@ -1069,11 +1017,6 @@ struct icaltimetype icaltime_set_timezone(struct icaltimetype *t, const icaltime
     }
 
     t->zone = zone;
-    if (zone == icaltimezone_get_utc_timezone()) {
-        t->is_utc = 1;
-    } else {
-        t->is_utc = 0;
-    }
 
     return *t;
 }
