@@ -2,29 +2,18 @@
  FILE:
  CREATOR: eric 25 June 2000
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
- The contents of this file are subject to the Mozilla Public License
- Version 1.0 (the "License"); you may not use this file except in
- compliance with the License. You may obtain a copy of the License at
- http://www.mozilla.org/MPL/
-
- Software distributed under the License is distributed on an "AS IS"
- basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
- the License for the specific language governing rights and
- limitations under the License.
-
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at https://www.mozilla.org/MPL/
 
  The Initial Developer of the Original Code is Eric Busboom
 ======================================================================*/
@@ -46,7 +35,7 @@
     );
 */
 
-char *major_type_string[] = {
+const char *major_type_string[] = {
     "TEXT",
     "IMAGE",
     "AUDIO",
@@ -58,7 +47,7 @@ char *major_type_string[] = {
     "NO"
 };
 
-char *minor_type_string[] = {
+const char *minor_type_string[] = {
     "ANY",
     "PLAIN",
     "RFC822",
@@ -227,6 +216,7 @@ int main(int argc, char *argv[])
         }
         last = i;
 
+        assert(size > 0);
         buf = malloc(size * 2);
         assert(buf != 0);
 
@@ -236,7 +226,7 @@ int main(int argc, char *argv[])
             memset(buf, 0, size * 2);
             /* First insert some non-randomized lines */
             non_rand = (unsigned int)(((float)rand() / (float)RAND_MAX) * last);
-            for (i = 0; i < non_rand; i++) {
+            for (i = 0; i < last && i < non_rand; i++) {
                 strcat(buf, array[i]);
             }
 
